[Schmitzm-commits] r715 - in trunk: doc src/schmitzm/jfree/chart/style

scm-commit@wald.intevation.org scm-commit at wald.intevation.org
Mon Feb 22 17:35:59 CET 2010


Author: mojays
Date: 2010-02-22 17:35:56 +0100 (Mon, 22 Feb 2010)
New Revision: 715

Modified:
   trunk/doc/Chart style XML structure.pdf
   trunk/src/schmitzm/jfree/chart/style/ChartStyleXMLFactory.java
   trunk/src/schmitzm/jfree/chart/style/ScatterChartStyle.java
Log:
Chart documentation (PDF) updated
Plot orientation default for scatter chart always VERTICAL (at construction time).
Default plot orientation (at chart XML import) VERTICAL.


Modified: trunk/doc/Chart style XML structure.pdf
===================================================================
(Binary files differ)

Modified: trunk/src/schmitzm/jfree/chart/style/ChartStyleXMLFactory.java
===================================================================
--- trunk/src/schmitzm/jfree/chart/style/ChartStyleXMLFactory.java	2010-02-21 19:17:34 UTC (rev 714)
+++ trunk/src/schmitzm/jfree/chart/style/ChartStyleXMLFactory.java	2010-02-22 16:35:56 UTC (rev 715)
@@ -131,7 +131,7 @@
       chartStyle.setBorderVisible( borderVisible );
 
     // Plot orientation
-    String orientationStr = XMLUtil.getAttribute(element,"orientation","horizontal");
+    String orientationStr = XMLUtil.getAttribute(element,"orientation","vertical");
     if ("horizontal".equalsIgnoreCase(orientationStr))
       chartStyle.setOrientation( PlotOrientation.HORIZONTAL );
     else if ("vertical".equalsIgnoreCase(orientationStr))

Modified: trunk/src/schmitzm/jfree/chart/style/ScatterChartStyle.java
===================================================================
--- trunk/src/schmitzm/jfree/chart/style/ScatterChartStyle.java	2010-02-21 19:17:34 UTC (rev 714)
+++ trunk/src/schmitzm/jfree/chart/style/ScatterChartStyle.java	2010-02-22 16:35:56 UTC (rev 715)
@@ -32,6 +32,7 @@
 import java.awt.Color;
 
 import org.jfree.chart.JFreeChart;
+import org.jfree.chart.plot.PlotOrientation;
 import org.jfree.chart.renderer.xy.XYItemRenderer;
 import org.jfree.data.general.Dataset;
 import org.jfree.data.xy.XYDataset;
@@ -52,11 +53,13 @@
   protected boolean regrLineVisible = true;
 
   /**
    * Creates a scatter chart style a regression line shown.
    * @param id   a (unique) ID for the style
    */
   public ScatterChartStyle(String id) {
     super(id, ChartType.SCATTER);
+    // Orientierung fuer Scatter immer Vertical 
+    setOrientation( PlotOrientation.VERTICAL );
   }
 
   /**
@@ -52,11 +53,13 @@
 
   /**
-   * Creates a scatter chart style a regression line shown.
+   * Creates a scatter chart style (with vertical orientation) a regression line shown.
    * @param id   a (unique) ID for the style
    */



More information about the Schmitzm-commits mailing list